@@ -54,7 +54,7 @@ class CryptoComApi:
 
     error = None
 
-    def __init__(self, key=None, secret=None, version=ApiVersion.V1):
+    def __init__(self, key=None, secret=None, version=ApiVersion.V2):
         self.version = CryptoComApi.ApiVersion(version)
         self.API_ROOT = self._API_VERSION_ROOT_PATH[self.version]
 
@@ -179,7 +179,7 @@ class CryptoComApi:
 
     ### Market Group ###
     # List all available market symbols
-    def symbols(self):
+    def symbols(self, **kwargs):
         path = {
             CryptoComApi.ApiVersion.V1: "symbols",
             CryptoComApi.ApiVersion.V2: "public/get-instruments",
@@ -187,7 +187,7 @@ class CryptoComApi:
         return self._request(path[self.version])
 
     # Get tickers in all available markets
-    def tickers(self, param=None):
+    def tickers(self, param=None, **kwargs):
         path = {
             CryptoComApi.ApiVersion.V1: "ticker",
             CryptoComApi.ApiVersion.V2: "public/get-ticker",
@@ -195,7 +195,7 @@ class CryptoComApi:
         return self._request(path[self.version], param=param)
 
     # Get ticker for a particular market
-    def ticker(self, symbol):
+    def ticker(self, symbol, **kwargs):
         param = {
             CryptoComApi.ApiVersion.V1: {'symbol': symbol},
             CryptoComApi.ApiVersion.V2: {'instrument_name': symbol},
@@ -203,13 +203,13 @@ class CryptoComApi:
         return self.tickers(param[self.version])
 
     # Get k-line data over a specified period
-    def klines(self, symbol, period):
+    def klines(self, symbol, period, **kwargs):
         if self.version != CryptoComApi.ApiVersion.V1:
             return {}
         return self._request('klines', param={'symbol': symbol, 'period': period})
 
     # Get last 200 trades in a specified market
-    def trades(self, symbol):
+    def trades(self, symbol, **kwargs):
         path = {
             CryptoComApi.ApiVersion.V1: "trades",
             CryptoComApi.ApiVersion.V2: "public/get-trades",
@@ -221,13 +221,13 @@ class CryptoComApi:
         return self._request(path[self.version], param[self.version])
 
     # Get latest execution price for all markets
-    def prices(self):
+    def prices(self, **kwargs):
         if self.version != CryptoComApi.ApiVersion.V1:
             return {}
         return self._request('ticker/price')
 
     # Get the order book for a particular market, type: step0, step1, step2 (step0 is the highest accuracy)
-    def order_book(self, symbol, _type='step0'):
+    def order_book(self, symbol, _type='step0', **kwargs):
         path = {
             CryptoComApi.ApiVersion.V1: "depth",
             CryptoComApi.ApiVersion.V2: "public/get-book",
@@ -240,7 +240,7 @@ class CryptoComApi:
 
     #####################################
     # User Group #
-    def balance(self, currency=None):
+    def balance(self, currency=None, **kwargs):
         """
         List all account balance of user
 
@@ -278,7 +278,7 @@ class CryptoComApi:
         }
         return self._post(path[self.version], params=param[self.version])
 
-    def create_order(self, symbol, side, _type, quantity=None, price=None, fee_coin=None, notional=None):
+    def create_order(self, symbol, side, _type, quantity=None, price=None, fee_coin=None, notional=None, client_oid=None, **kwargs):
         """
         creates a buy or sell order on exchange
 
@@ -293,6 +293,7 @@ class CryptoComApi:
         @param quantity: type=1: represents the quantity of sales and purchases; \
                          type=2: buy means the total price, Selling represents the total number.
 
+        @param notional:
         @return: { "order_id": 34343 }
         """
         path = {
@@ -322,19 +323,22 @@ class CryptoComApi:
             # For MARKET (BUY) Orders only - Amount to spend
             param[CryptoComApi.ApiVersion.V2]['notional'] = notional
 
-        if self.version != CryptoComApi.ApiVersion.V1:
+        if client_oid:
+            param[CryptoComApi.ApiVersion.V2]['client_oid'] = client_oid
+
+        if self.version == CryptoComApi.ApiVersion.V1:
             if fee_coin:
                 param[self.version]['fee_is_user_exchange_coin'] = fee_coin
 
         return self._post(path[self.version], params=param[self.version])
 
-    def create_limit_order(self, symbol, side, amount, price, fee_coin=None):
-        return self.create_order(symbol, side, LIMIT_ORDER, amount, price, fee_coin)
+    def create_limit_order(self, symbol, side, amount, price, fee_coin=None, client_oid=None, **kwargs):
+        return self.create_order(symbol, side, LIMIT_ORDER, amount, price, fee_coin, client_oid, **kwargs)
 
-    def create_market_order(self, symbol, side, total, fee_coin=None):
-        return self.create_order(symbol, side, MARKET_ORDER, total, None, fee_coin)
+    def create_market_order(self, symbol, side, total, fee_coin=None, client_oid=None, **kwargs):
+        return self.create_order(symbol, side, MARKET_ORDER, total, None, fee_coin, client_oid, **kwargs)
 
-    def show_order(self, symbol, order_id):
+    def show_order(self, symbol, order_id, **kwargs):
         """
         Get order detail
 
@@ -400,7 +404,7 @@ class CryptoComApi:
         }
         return self._post(path[self.version], params=param[self.version])
 
-    def cancel_order(self, symbol, order_id):
+    def cancel_order(self, symbol, order_id, **kwargs):
         """
         Cancel an order
 
@@ -418,7 +422,7 @@ class CryptoComApi:
         }
         return self._post(path[self.version], params=param[self.version])
 
-    def cancel_all_orders(self, symbol):
+    def cancel_all_orders(self, symbol, **kwargs):
         """
         Cancel all orders in a particular market
 
@@ -435,7 +439,7 @@ class CryptoComApi:
         }
         return self._post(path[self.version], params=param[self.version])
 
-    def open_orders(self, symbol=None, page_size=None, page_number=None):
+    def open_orders(self, symbol=None, page_size=None, page_number=None, **kwargs):
         """
         List all open orders in a particular market
 
@@ -460,7 +464,7 @@ class CryptoComApi:
             param[self.version]['page'] = page_number
         return self._post(path[self.version], params=param[self.version])
 
-    def all_orders(self, symbol, page_size=None, page_number=None, start=None, end=None):
+    def all_orders(self, symbol=None, page_size=None, page_number=None, start=None, end=None, **kwargs):
         """
         List all orders in a particular market (including executed, pending, cancelled orders)
 
@@ -477,7 +481,7 @@ class CryptoComApi:
         }
         param = {
             CryptoComApi.ApiVersion.V1: {'symbol': symbol},
-            CryptoComApi.ApiVersion.V2: {'instrument_name': symbol}
+            CryptoComApi.ApiVersion.V2: ({'instrument_name': symbol} if symbol else {})
         }
 
         if page_size:
@@ -493,7 +497,7 @@ class CryptoComApi:
             param[CryptoComApi.ApiVersion.V2]['end_ts'] = end
         return self._post(path[self.version], params=param[self.version])
 
-    def all_executed_orders(self, symbol, page_size=None, page_number=None, start=None, end=None, sort=None):
+    def all_executed_orders(self, symbol=None, page_size=None, page_number=None, start=None, end=None, sort=None, **kwargs):
         """
         List all executed orders
 
@@ -511,7 +515,7 @@ class CryptoComApi:
         }
         param = {
             CryptoComApi.ApiVersion.V1: {'symbol': symbol},
-            CryptoComApi.ApiVersion.V2: {'instrument_name': symbol},
+            CryptoComApi.ApiVersion.V2: ({'instrument_name': symbol} if symbol else {}),
         }
 
         if page_size:
